/**
 * The information about an apt package
 */
export type ApkPackage = {
    /** The name of the package */
    name: string;
    /** The version of the package (optional) */
    version?: string;
    /** The repository to add before installing the package (optional) */
    repository?: string;
    /**
     * If the given version is not available, fall back to the latest version
     * @default false
     */
    fallBackToLatest?: boolean;
};
/**
 * Check if a package is already installed
 * @param pkg The package to check
 * @returns Whether the package is installed
 */
export declare function checkPackageInstalled(pkg: ApkPackage): Promise<boolean>;
/**
 * Filter out packages that are already installed and qualify those that need installation
 * @param packages List of packages to check
 * @returns List of packages that need to be installed
 */
export declare function filterAndQualifyApkPackages(packages: ApkPackage[]): Promise<string[]>;
/**
 * Format a package with its version if specified
 * @param pkg The package object
 * @returns Formatted package string (name=version or just name)
 */
export declare function formatPackageWithVersion(pkg: ApkPackage): string;
